package com.xunmei.system.mapper;

import java.util.List;

import com.xunmei.system.api.domain.SysArea;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author xunmei
 * @date 2023-08-14
 */
@Mapper
public interface ISysAreaMapper extends BaseMapper<SysArea> {
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
     SysArea selectSysAreaById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param sysArea 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
     List<SysArea> selectSysAreaList(SysArea sysArea);

    /**
     * 新增【请填写功能名称】
     *
     * @param sysArea 【请填写功能名称】
     * @return 结果
     */
     int insertSysArea(SysArea sysArea);

    /**
     * 修改【请填写功能名称】
     *
     * @param sysArea 【请填写功能名称】
     * @return 结果
     */
     int updateSysArea(SysArea sysArea);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
     int deleteSysAreaById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteSysAreaByIds(Long[] ids);
}
